@@ -25,6 +25,9 @@ from io import open
 
 from blueman.Constants import *
 
+import gi
+gi.require_version("Gtk", "3.0")
+gi.require_version("Gdk", "3.0")
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import GdkPixbuf
@@ -61,7 +64,7 @@ def dprint(*args):
 
         s = ""
         for a in args:
-            s += (str(a) + " ")
+            s += ("%s " % a)
         co = sys._getframe(1).f_code
 
         fname = BOLD(co.co_name)
@@ -136,13 +139,14 @@ def enable_rgba_colormap():
     pass
 
 
-def launch(cmd, paths=None, system=False, icon_name=None, name="blueman"):
+def launch(cmd, paths=None, system=False, icon_name=None, sn=True, name="blueman"):
     '''Launch a gui app with starup notification'''
     display = Gdk.Display.get_default()
     timestamp = Gtk.get_current_event_time()
     context = display.get_app_launch_context()
     context.set_timestamp(timestamp)
-    flags = Gio.AppInfoCreateFlags.SUPPORTS_STARTUP_NOTIFICATION
+    if sn: flags = Gio.AppInfoCreateFlags.SUPPORTS_STARTUP_NOTIFICATION
+    else: flags = Gio.AppInfoCreateFlags.NONE
 
     env = os.environ
     env["BLUEMAN_EVENT_TIME"] = str(timestamp)
@@ -179,12 +183,12 @@ def get_icon(name, size=24, fallback="image-missing"):
 
     try:
         icon = ic.load_icon(name, size, 0)
-    except:
+    except GLib.Error:
         if not fallback:
             raise
         try:
             icon = ic.load_icon(fallback, size, 0)
-        except:
+        except GLib.Error:
             icon = ic.load_icon("image-missing", size, 0)
 
     if icon.props.width > size:
